@@ -665,7 +665,7 @@ void display_multiply(void)
 		snprintf(buf, sizeof(buf), "XX");
 	else	
 		snprintf(buf, sizeof(buf), "X%d", gi_bonus_multiply >> 1);
-	gfx_draw_text(buf, 800 - 2*SMALL_FONT_WIDTH, 480 - SMALL_FONT_HEIGHT - 4, 0);
+	gfx_draw_text(buf, 800 - 2*SMALL_FONT_WIDTH, 480 - SMALL_FONT_HEIGHT - 4, 0); // This is a small niche for it to the right of the time bar
 }
 
 void display_time(float num)
@@ -691,14 +691,14 @@ void display_hi_score(void)
 		snprintf(score, sizeof(score),"%06d", gi_high_score);
 	else	
 		snprintf(score, sizeof(score),"%06d", gi_notime_high_score);
-	gfx_draw_text(score, 30, 120, 1);
+	gfx_draw_text(score, 30, 120, BIG_FONT);
 }
 
 void display_current_score(void)
 {
 	char score[64];
 	snprintf(score, sizeof(score),"%06d", gi_current_score);
-	gfx_draw_text(score, 30, 200, 1);
+	gfx_draw_text(score, 30, 200, BIG_FONT);
 }
 
 gboolean board_engine_loop (gpointer data)
@@ -986,7 +986,7 @@ void gweled_draw_message_at (gchar * in_message, gint msg_x, gint msg_y)
 	message = g_ascii_strup (in_message, -1);
 
 	for (i = 0; i < strlen (message); i++)
-		gweled_draw_character (msg_x + i * SMALL_FONT_WIDTH, msg_y, 1,
+		gweled_draw_character (msg_x + i * MEDIUM_FONT_WIDTH, msg_y, 1,
 				       message[i]);
 
 	free (message);
@@ -996,9 +996,9 @@ void gweled_draw_message (gchar * in_message)
 {
 	gint msg_x, msg_y, msg_w;
 
-	msg_w = SMALL_FONT_WIDTH * strlen (in_message);
+	msg_w = MEDIUM_FONT_WIDTH * strlen (in_message);
 	msg_x = (BOARD_WIDTH * TILE_WIDTH - msg_w) >> 1;
-	msg_y = (BOARD_HEIGHT * TILE_HEIGHT - SMALL_FONT_HEIGHT) >> 1;
+	msg_y = (BOARD_HEIGHT * TILE_HEIGHT - MEDIUM_FONT_HEIGHT) >> 1;
 
 	gweled_draw_message_at (in_message, msg_x, msg_y);
 }
