@@ -15,13 +15,21 @@ gint gi_gems_pixbuf[7];
 gint gi_tiles_bg_pixbuf[2];
 gint gi_cursor_pixbuf;
 gint gi_small_charset_pixbuf[50];
+gint gi_medium_charset_pixbuf[50];
 gint gi_big_charset_pixbuf[50];
 
-#define SMALL_FONT_WIDTH	36
-#define SMALL_FONT_HEIGHT	30
+#define SMALL_FONT_WIDTH	24
+#define SMALL_FONT_HEIGHT	20
 
-#define BIG_FONT_WIDTH	48
-#define BIG_FONT_HEIGHT	40
+#define MEDIUM_FONT_WIDTH	36
+#define MEDIUM_FONT_HEIGHT	30
+
+#define BIG_FONT_WIDTH		48
+#define BIG_FONT_HEIGHT		40
+
+#define SMALL_FONT	0
+#define MEDIUM_FONT	1
+#define BIG_FONT	2
 
 
 extern gint gi_gems_pixbuf[7];
